Basic trace context foundation for observability core
Provides W3C trace context implementation and basic context management ports. Domain-specific implementations (LLM, A2A, etc.) are provided by higher-level crates.
Structs
- Context
Future - Future wrapper that restores trace context across async poll boundaries.
- Header
Extractor - Header extractor for W3C trace context propagation
- Header
Injector - Header injector for W3C trace context propagation
- Trace
Context - Simplified trace context for internal use
- W3CTrace
Context - W3C Trace Context implementation for distributed tracing
Functions
- clear_
current_ context - Clear the current trace context
- get_
current_ context - Get the current trace context for this thread
- set_
current_ context - Set the current trace context for this thread
- with_
context - Execute a function with a specific trace context
- with_
context_ future - Execute a future with a specific trace context re-applied on every poll.