NoOpObservabilityPlugin

Struct NoOpObservabilityPlugin 

pub struct NoOpObservabilityPlugin;
No-op observability plugin that does nothing

This implementation provides zero runtime cost when observability is disabled. All methods are inlined and compile to nothing in release builds.

Implementations

Source

impl NoOpObservabilityPlugin

pub fn new() -> Self

Create a new no-op plugin

pub fn shared() -> Arc<Self>

Create an Arc’d no-op plugin for sharing